aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorbors-servo <lbergstrom+bors@mozilla.com>2017-02-16 18:16:28 -0800
committerGitHub <noreply@github.com>2017-02-16 18:16:28 -0800
commit3fa9ce16db910c0b44617dafdcd8e76b6f813c61 (patch)
tree863433cd79764d59e579385031af3adfb6d00662
parent6adbcb4ccdc1f74638b0c6e990c122e34bc967e4 (diff)
parent33338cab9d3a40f4173b0ef40d85ed81a5398bb1 (diff)
downloadservo-3fa9ce16db910c0b44617dafdcd8e76b6f813c61.tar.gz
servo-3fa9ce16db910c0b44617dafdcd8e76b6f813c61.zip
Auto merge of #15594 - mbrubeck:align-content-fix, r=Manishearth
Fix initial value of align-content and justify-content This fixes a trivial mistake in #15533, caused by me misreading the spec. r? @Manishearth <!-- Reviewable:start --> --- This change is [<img src="https://reviewable.io/review_button.svg" height="34" align="absmiddle" alt="Reviewable"/>](https://reviewable.io/reviews/servo/servo/15594) <!-- Reviewable:end -->
-rw-r--r--components/style/properties/longhand/position.mako.rs12
-rw-r--r--components/style/values/specified/align.rs6
2 files changed, 9 insertions, 9 deletions
diff --git a/components/style/properties/longhand/position.mako.rs b/components/style/properties/longhand/position.mako.rs
index b169f74c396..43a740eca31 100644
--- a/components/style/properties/longhand/position.mako.rs
+++ b/components/style/properties/longhand/position.mako.rs
@@ -88,13 +88,13 @@ ${helpers.single_keyword("flex-wrap", "nowrap wrap wrap-reverse",
// FIXME: Update Servo to support the same Syntax as Gecko.
${helpers.single_keyword("justify-content", "stretch flex-start flex-end center space-between space-around",
extra_prefixes="webkit",
- spec="https://drafts.csswg.org/css-flexbox/#justify-content-property",
+ spec="https://drafts.csswg.org/css-align/#propdef-justify-content",
animatable=False)}
% else:
${helpers.predefined_type(name="justify-content",
type="AlignJustifyContent",
- initial_value="specified::AlignJustifyContent::auto()",
- spec="https://drafts.csswg.org/css-flexbox/#justify-content-property",
+ initial_value="specified::AlignJustifyContent::normal()",
+ spec="https://drafts.csswg.org/css-align/#propdef-justify-content",
extra_prefixes="webkit",
animatable=False)}
% endif
@@ -113,13 +113,13 @@ ${helpers.single_keyword("align-items", "stretch flex-start flex-end center base
// FIXME: Update Servo to support the same Syntax as Gecko.
${helpers.single_keyword("align-content", "stretch flex-start flex-end center space-between space-around",
extra_prefixes="webkit",
- spec="https://drafts.csswg.org/css-flexbox/#align-content-property",
+ spec="https://drafts.csswg.org/css-align/#propdef-align-content",
animatable=False)}
% else:
${helpers.predefined_type(name="align-content",
type="AlignJustifyContent",
- initial_value="specified::AlignJustifyContent::auto()",
- spec="https://drafts.csswg.org/css-flexbox/#align-content-property",
+ initial_value="specified::AlignJustifyContent::normal()",
+ spec="https://drafts.csswg.org/css-align/#propdef-align-content",
extra_prefixes="webkit",
animatable=False)}
% endif
diff --git a/components/style/values/specified/align.rs b/components/style/values/specified/align.rs
index 26291f219e6..3665229dac6 100644
--- a/components/style/values/specified/align.rs
+++ b/components/style/values/specified/align.rs
@@ -117,10 +117,10 @@ const ALIGN_ALL_SHIFT: u32 = structs::NS_STYLE_ALIGN_ALL_SHIFT;
pub struct AlignJustifyContent(u16);
impl AlignJustifyContent {
/// The initial value 'auto'
#[inline]
- pub fn auto() -> Self {
- Self::new(ALIGN_AUTO)
+ pub fn normal() -> Self {
+ Self::new(ALIGN_NORMAL)
}
/// Construct a value with no fallback.
@@ -117,10 +117,10 @@ const ALIGN_ALL_SHIFT: u32 = structs::NS_STYLE_ALIGN_ALL_SHIFT;
pub struct AlignJustifyContent(u16);
impl AlignJustifyContent {
- /// The initial value 'auto'
+ /// The initial value 'normal'
#[inline]